@@ -48,9 +48,15 @@ class AnthyFactory : public IMEngineFactoryBase
     String       m_period_style;
     String       m_space_type;
     bool         m_auto_convert;
+    bool         m_close_cand_win_on_select;
+    String       m_dict_admin_command;
+    String       m_add_word_command;
     bool         m_show_input_mode_label;
     bool         m_show_typing_method_label;
     bool         m_show_period_style_label;
+    bool         m_show_dict_label;
+    bool         m_show_dict_admin_label;
+    bool         m_show_add_word_label;
 
     /* for key bindings */
     KeyEventList m_commit_keys;
@@ -79,6 +85,8 @@ class AnthyFactory : public IMEngineFactoryBase
     KeyEventList m_candidates_page_up_keys;
     KeyEventList m_candidates_page_down_keys;
 
+    KeyEventList m_select_candidate_keys[10];
+
     KeyEventList m_conv_to_hiragana_keys;
     KeyEventList m_conv_to_katakana_keys;
     KeyEventList m_conv_to_half_katakana_keys;
@@ -89,6 +97,9 @@ class AnthyFactory : public IMEngineFactoryBase
     KeyEventList m_wide_latin_mode_keys;
     KeyEventList m_circle_kana_mode_keys;
 
+    KeyEventList m_dict_admin_keys;
+    KeyEventList m_add_word_keys;
+
 public:
     AnthyFactory (const String &lang,
                   const String &uuid,
@@ -102,7 +113,8 @@ public:
     virtual String      get_uuid () const;
     virtual String      get_icon_file () const;
 
-    virtual IMEngineInstancePointer create_instance (const String& encoding, int id = -1);
+    virtual IMEngineInstancePointer create_instance (const String& encoding,
+                                                     int id = -1);
 
 private:
     void reload_config (const ConfigPointer &config);
@@ -148,9 +160,11 @@ private:
     void   install_properties                 (void);
     void   set_input_mode                     (InputMode mode);
     void   set_typing_method                  (TypingMethod method); /* FIXME! */
-    void   set_period_style                   (PeriodStyle style);
+    void   set_period_style                   (PeriodStyle period,
+                                               CommaStyle comma);
     bool   is_selecting_candidates            (void);
-    bool   convert_kana                       (SpecialCandidate type);
+    void   select_candidate_no_direct         (unsigned int item);
+    bool   convert_kana                       (CandidateType type);
 
     /* processing key event */
     bool   process_key_event_lookup_keybind   (const KeyEvent &key);
@@ -186,6 +200,19 @@ private:
     bool   action_candidates_page_up          (void);
     bool   action_candidates_page_down        (void);
 
+    bool   action_select_candidate            (unsigned int i);
+
+    bool   action_select_candidate_1          (void);
+    bool   action_select_candidate_2          (void);
+    bool   action_select_candidate_3          (void);
+    bool   action_select_candidate_4          (void);
+    bool   action_select_candidate_5          (void);
+    bool   action_select_candidate_6          (void);
+    bool   action_select_candidate_7          (void);
+    bool   action_select_candidate_8          (void);
+    bool   action_select_candidate_9          (void);
+    bool   action_select_candidate_10         (void);
+
     bool   action_convert_to_hiragana         (void);
     bool   action_convert_to_katakana         (void);
     bool   action_convert_to_half_katakana    (void);
@@ -198,13 +225,15 @@ private:
     bool   action_toggle_latin_mode           (void);
     bool   action_toggle_wide_latin_mode      (void);
 
+    bool   action_add_word                    (void);
+    bool   action_launch_dict_admin_tool      (void);
     /*
     void   actoin_regist_word                 (void);
-    void   actoin_launch_dict_admin           (void);
     */
 
     /* utility */
-    bool   match_key_event (const KeyEventList &keys, const KeyEvent &key) const;
+    bool   match_key_event (const KeyEventList &keys,
+                            const KeyEvent &key) const;
 };
 #endif /* __SCIM_ANTHY_IMENGINE_H__ */
 /*
